Module outbound

Module outbound 

Native outbound connector for proxy chains.

This module provides OutboundConnector, which compiles a TOML config and executes the chain engine directly to open TCP connections through a configured proxy chain without starting a listener service.

Structs

OutboundConnector
A native outbound connector that executes the chain engine directly.
OutboundInfo
Metadata about an established outbound connection.
UdpAssociation
A UDP association through a SOCKS5 proxy.